@@ -2,6 +2,7 @@ from pathlib import Path
 import subprocess
 from uuid import uuid4
 from statistics import mean
+import shutil
 
 class Language:
     """
@@ -34,6 +35,9 @@ class Language:
         with open(workdir / self.source.format(name=name), 'w') as f:
             f.write(source)
 
+    def copy_source(self, workdir, name, dest):
+        shutil.copy(workdir / self.source.format(name=name), dest)
+
     def cleanup(self, workdir, name):
         (workdir / self.source.format(name=name)).unlink()
         for artefact in self.artefacts:
@@ -179,5 +183,8 @@ class Program():
         test_results = [correctness(output_lines, self.run(input_lines)) for input_lines, output_lines in test_cases]
         return sum(test_results) / len(test_results)
 
+    def save(self, path):
+        self.language.copy_source(self.workdir, self.name, path)
+
     def __del__(self):
         self.language.cleanup(self.workdir, self.name)
\ No newline at end of file
